@@ -5,13 +5,34 @@ Created on Mon Apr 26 18:08:49 2021
 
 @author: nattawoot
 """
+import pandas as pd
+import os
 import copy
 from collections import namedtuple
+from dataclasses import dataclass
+from datetime import datetime
+
+
 from wud.aws import s3bucket_json_get
 
 convar_dict = s3bucket_json_get('wud-cloudhouse','maruball_convar.json')
 
-def team_name_revise(team, source_input, source_output):
+
+
+@dataclass
+class MatchBet:
+    league: str = ''
+    kot: datetime = ''
+    team_home: str = ''
+    team_away: str = ''
+    hdc: float = ''
+    hdc_side: str = ''
+    odd_home: float = ''
+    odd_away: float = ''
+    source: str = ''
+    
+
+def team_name_revise0(team, source_input, source_output):
     
     
     epl = copy.deepcopy(convar_dict['team_name']['epl'])
@@ -19,7 +40,7 @@ def team_name_revise(team, source_input, source_output):
     tpl = copy.deepcopy(convar_dict['team_name']['tpl'])
     etc = copy.deepcopy(convar_dict['team_name']['etc'])
 
-    Team = namedtuple("Team", ['footballapi', 'livescore', 'shortname', 'league'])   
+    Team = namedtuple("Team", ['footballapi', 'livescore', 'short', 'league'])   
 
     
     
@@ -48,4 +69,15 @@ def team_name_revise(team, source_input, source_output):
             break
         
     return result
-       
+
+def team_name_revise(team, source_input, source_output):
+    
+    this_folder = os.path.dirname(os.path.abspath(__file__))
+
+    df = pd.read_csv(os.path.join(this_folder,'football_team_name.csv'))
+    try:
+        row = df.loc[df[source_input] == team]
+        result = row.iloc[0][source_output]
+    except (IndexError, KeyError):
+        result = team
+    return result       
